==> miro_0.9.8.1.orig.tar.gz: Miro-2007-07-24/platform/gtk-x11/frontend_implementation/Application.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005-2007 Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import gtk

import threading
from frontend_implementation.gtk_queue import queue
import gtcache
import config
import prefs
import gtk.glade
import platformutils

###############################################################################
#### Application object                                                    ####
###############################################################################

class Application:

    def __init__(self):
        #print "Application init"
        pass
    def Run(self):
        gtk.glade.bindtextdomain("miro", config.get(prefs.GETTEXT_PATHNAME))
        gtk.glade.textdomain("miro")

        queue.main_thread = threading.currentThread()
        platformutils.setMainThread()
        gtk.gdk.threads_init()
        self.onStartup()
        gtk.main()
        self.onShutdown()

    def onStartup(self):
        # For overriding
        pass

    def finishStartupSequence(self):
        pass

    def onShutdown(self):
        # For overriding
        pass

    def addAndSelectFeed(self, url):
        # For overriding
        pass

###############################################################################
###############################################################################

==> miro_1.1.2.orig.tar.gz: Miro-1.1.2/platform/gtk-x11/frontend_implementation/Application.py <==
# Miro - an RSS based video player application
# Copyright (C) 2005-2007 Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.

import gtk

import threading
from frontend_implementation.gtk_queue import queue
import gtcache
import config
import prefs
import gtk.glade
import platformutils

###############################################################################
#### Application object                                                    ####
###############################################################################

class Application:

    def __init__(self):
        #print "Application init"
        pass
    def Run(self):
        gtk.glade.bindtextdomain("miro", config.get(prefs.GETTEXT_PATHNAME))
        gtk.glade.textdomain("miro")

        queue.main_thread = threading.currentThread()
        platformutils.setMainThread()
        gtk.gdk.threads_init()
        # We import frontend here to avoid a recursive import, since frontend
        # imports this file
        import frontend
        if frontend.themeName is not None:
            config.load(frontend.themeName)
        self.onStartup()
        gtk.main()
        self.onShutdown()

    def onStartup(self):
        # For overriding
        pass

    def finishStartupSequence(self):
        pass

    def onShutdown(self):
        # For overriding
        pass

    def addAndSelectFeed(self, url):
        # For overriding
        pass

###############################################################################
###############################################################################
